Struct aws_sdk_iotthingsgraph::client::fluent_builders::AssociateEntityToThing[][src]

pub struct AssociateEntityToThing<C = DynConnector, M = AwsMiddleware, R = Standard> { /* fields omitted */ }
Fluent builder constructing a request to AssociateEntityToThing.

Associates a device with a concrete thing that is in the user's registry.

A thing can be associated with only one device at a time. If you associate a thing with a new device id, its previous association will be removed.

Implementations

Sends the request and returns the response.

If an error occurs, an SdkError will be returned with additional details that can be matched against.

By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.

The name of the thing to which the entity is to be associated.

The name of the thing to which the entity is to be associated.

The ID of the device to be associated with the thing.

The ID should be in the following format.

urn:tdm:REGION/ACCOUNT ID/default:device:DEVICENAME

The ID of the device to be associated with the thing.

The ID should be in the following format.

urn:tdm:REGION/ACCOUNT ID/default:device:DEVICENAME

The version of the user's namespace. Defaults to the latest version of the user's namespace.

The version of the user's namespace. Defaults to the latest version of the user's namespace.