Struct aws_sdk_iotthingsgraph::client::fluent_builders::DescribeNamespace[][src]

pub struct DescribeNamespace<C = DynConnector, M = AwsMiddleware, R = Standard> { /* fields omitted */ }
Fluent builder constructing a request to DescribeNamespace.

Gets the latest version of the user's namespace and the public version that it is tracking.

Implementations

Sends the request and returns the response.

If an error occurs, an SdkError will be returned with additional details that can be matched against.

By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.

The name of the user's namespace. Set this to aws to get the public namespace.

The name of the user's namespace. Set this to aws to get the public namespace.