Struct aws_sdk_iotthingsgraph::client::fluent_builders::DissociateEntityFromThing[][src]

pub struct DissociateEntityFromThing<C = DynConnector, M = AwsMiddleware, R = Standard> { /* fields omitted */ }
Fluent builder constructing a request to DissociateEntityFromThing.

Dissociates a device entity from a concrete thing. The action takes only the type of the entity that you need to dissociate because only one entity of a particular type can be associated with a thing.

Implementations

Sends the request and returns the response.

If an error occurs, an SdkError will be returned with additional details that can be matched against.

By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.

The name of the thing to disassociate.

The name of the thing to disassociate.

The entity type from which to disassociate the thing.

The entity type from which to disassociate the thing.