Struct aws_sdk_iotthingsgraph::client::fluent_builders::GetSystemInstance[][src]

pub struct GetSystemInstance<C = DynConnector, M = AwsMiddleware, R = Standard> { /* fields omitted */ }
Fluent builder constructing a request to GetSystemInstance.

Gets a system instance.

Implementations

Sends the request and returns the response.

If an error occurs, an SdkError will be returned with additional details that can be matched against.

By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.

The ID of the system deployment instance. This value is returned by CreateSystemInstance.

The ID should be in the following format.

urn:tdm:REGION/ACCOUNT ID/default:deployment:DEPLOYMENTNAME

The ID of the system deployment instance. This value is returned by CreateSystemInstance.

The ID should be in the following format.

urn:tdm:REGION/ACCOUNT ID/default:deployment:DEPLOYMENTNAME