Struct aws_sdk_iotthingsgraph::client::fluent_builders::GetSystemTemplate[][src]

pub struct GetSystemTemplate<C = DynConnector, M = AwsMiddleware, R = Standard> { /* fields omitted */ }
Fluent builder constructing a request to GetSystemTemplate.

Gets a system.

Implementations

Sends the request and returns the response.

If an error occurs, an SdkError will be returned with additional details that can be matched against.

By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.

The ID of the system to get. This ID must be in the user's namespace.

The ID should be in the following format.

urn:tdm:REGION/ACCOUNT ID/default:system:SYSTEMNAME

The ID of the system to get. This ID must be in the user's namespace.

The ID should be in the following format.

urn:tdm:REGION/ACCOUNT ID/default:system:SYSTEMNAME

The number that specifies the revision of the system to get.

The number that specifies the revision of the system to get.