Struct aws_sdk_iotthingsgraph::client::fluent_builders::SearchSystemInstances[][src]

pub struct SearchSystemInstances<C = DynConnector, M = AwsMiddleware, R = Standard> { /* fields omitted */ }
Fluent builder constructing a request to SearchSystemInstances.

Searches for system instances in the user's account.

Implementations

Sends the request and returns the response.

If an error occurs, an SdkError will be returned with additional details that can be matched against.

By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.

Appends an item to filters.

To override the contents of this collection use set_filters.

Optional filter to apply to the search. Valid filters are SYSTEM_TEMPLATE_ID, STATUS, and GREENGRASS_GROUP_NAME.

Multiple filters function as OR criteria in the query. Multiple values passed inside the filter function as AND criteria.

Optional filter to apply to the search. Valid filters are SYSTEM_TEMPLATE_ID, STATUS, and GREENGRASS_GROUP_NAME.

Multiple filters function as OR criteria in the query. Multiple values passed inside the filter function as AND criteria.

The string that specifies the next page of results. Use this when you're paginating results.

The string that specifies the next page of results. Use this when you're paginating results.

The maximum number of results to return in the response.

The maximum number of results to return in the response.