Struct aws_sdk_iotthingsgraph::client::Client [−][src]
pub struct Client<C = DynConnector, M = AwsMiddleware, R = Standard> { /* fields omitted */ }Expand description
An ergonomic service client for IotThingsGraphFrontEndService.
This client allows ergonomic access to a IotThingsGraphFrontEndService-shaped service.
Each method corresponds to an endpoint defined in the service’s Smithy model,
and the request and response shapes are auto-generated from that same model.
Using a Client
Once you have a client set up, you can access the service’s endpoints
by calling the appropriate method on Client. Each such method
returns a request builder for that endpoint, with methods for setting
the various fields of the request. Once your request is complete, use
the send method to send the request. send returns a future, which
you then have to .await to get the service’s response.
Implementations
impl<C, M, R> Client<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
impl<C, M, R> Client<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
Constructs a fluent builder for the AssociateEntityToThing operation.
See AssociateEntityToThing for more information about the
operation and its arguments.
Constructs a fluent builder for the CreateFlowTemplate operation.
See CreateFlowTemplate for more information about the
operation and its arguments.
Constructs a fluent builder for the CreateSystemInstance operation.
See CreateSystemInstance for more information about the
operation and its arguments.
Constructs a fluent builder for the CreateSystemTemplate operation.
See CreateSystemTemplate for more information about the
operation and its arguments.
Constructs a fluent builder for the DeleteFlowTemplate operation.
See DeleteFlowTemplate for more information about the
operation and its arguments.
Constructs a fluent builder for the DeleteNamespace operation.
See DeleteNamespace for more information about the
operation and its arguments.
Constructs a fluent builder for the DeleteSystemInstance operation.
See DeleteSystemInstance for more information about the
operation and its arguments.
Constructs a fluent builder for the DeleteSystemTemplate operation.
See DeleteSystemTemplate for more information about the
operation and its arguments.
Constructs a fluent builder for the DeploySystemInstance operation.
See DeploySystemInstance for more information about the
operation and its arguments.
Constructs a fluent builder for the DeprecateFlowTemplate operation.
See DeprecateFlowTemplate for more information about the
operation and its arguments.
Constructs a fluent builder for the DeprecateSystemTemplate operation.
See DeprecateSystemTemplate for more information about the
operation and its arguments.
Constructs a fluent builder for the DescribeNamespace operation.
See DescribeNamespace for more information about the
operation and its arguments.
Constructs a fluent builder for the DissociateEntityFromThing operation.
See DissociateEntityFromThing for more information about the
operation and its arguments.
Constructs a fluent builder for the GetEntities operation.
See GetEntities for more information about the
operation and its arguments.
Constructs a fluent builder for the GetFlowTemplate operation.
See GetFlowTemplate for more information about the
operation and its arguments.
Constructs a fluent builder for the GetFlowTemplateRevisions operation.
See GetFlowTemplateRevisions for more information about the
operation and its arguments.
Constructs a fluent builder for the GetNamespaceDeletionStatus operation.
See GetNamespaceDeletionStatus for more information about the
operation and its arguments.
Constructs a fluent builder for the GetSystemInstance operation.
See GetSystemInstance for more information about the
operation and its arguments.
Constructs a fluent builder for the GetSystemTemplate operation.
See GetSystemTemplate for more information about the
operation and its arguments.
Constructs a fluent builder for the GetSystemTemplateRevisions operation.
See GetSystemTemplateRevisions for more information about the
operation and its arguments.
Constructs a fluent builder for the GetUploadStatus operation.
See GetUploadStatus for more information about the
operation and its arguments.
Constructs a fluent builder for the ListFlowExecutionMessages operation.
See ListFlowExecutionMessages for more information about the
operation and its arguments.
Constructs a fluent builder for the ListTagsForResource operation.
See ListTagsForResource for more information about the
operation and its arguments.
Constructs a fluent builder for the SearchEntities operation.
See SearchEntities for more information about the
operation and its arguments.
Constructs a fluent builder for the SearchFlowExecutions operation.
See SearchFlowExecutions for more information about the
operation and its arguments.
Constructs a fluent builder for the SearchFlowTemplates operation.
See SearchFlowTemplates for more information about the
operation and its arguments.
Constructs a fluent builder for the SearchSystemInstances operation.
See SearchSystemInstances for more information about the
operation and its arguments.
Constructs a fluent builder for the SearchSystemTemplates operation.
See SearchSystemTemplates for more information about the
operation and its arguments.
Constructs a fluent builder for the SearchThings operation.
See SearchThings for more information about the
operation and its arguments.
Constructs a fluent builder for the TagResource operation.
See TagResource for more information about the
operation and its arguments.
Constructs a fluent builder for the UndeploySystemInstance operation.
See UndeploySystemInstance for more information about the
operation and its arguments.
Constructs a fluent builder for the UntagResource operation.
See UntagResource for more information about the
operation and its arguments.
Constructs a fluent builder for the UpdateFlowTemplate operation.
See UpdateFlowTemplate for more information about the
operation and its arguments.
Constructs a fluent builder for the UpdateSystemTemplate operation.
See UpdateSystemTemplate for more information about the
operation and its arguments.
Constructs a fluent builder for the UploadEntityDefinitions operation.
See UploadEntityDefinitions for more information about the
operation and its arguments.
Creates a client with the given service config and connector override.