Enum aws_sdk_iotthingsgraph::error::DeleteSystemTemplateErrorKind [−][src]
#[non_exhaustive]
pub enum DeleteSystemTemplateErrorKind {
InternalFailureException(InternalFailureException),
InvalidRequestException(InvalidRequestException),
ResourceInUseException(ResourceInUseException),
ThrottlingException(ThrottlingException),
Unhandled(Box<dyn Error + Send + Sync + 'static>),
}Expand description
Types of errors that can occur for the DeleteSystemTemplate operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InternalFailureException(InternalFailureException)Tuple Fields of InternalFailureException
InvalidRequestException(InvalidRequestException)Tuple Fields of InvalidRequestException
ResourceInUseException(ResourceInUseException)Tuple Fields of ResourceInUseException
ThrottlingException(ThrottlingException)Tuple Fields of ThrottlingException
An unexpected error, e.g. invalid JSON returned by the service or an unknown error code