Struct aws_sdk_iotthingsgraph::input::associate_entity_to_thing_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for AssociateEntityToThingInput
Implementations
The name of the thing to which the entity is to be associated.
The name of the thing to which the entity is to be associated.
The ID of the device to be associated with the thing.
The ID should be in the following format.
urn:tdm:REGION/ACCOUNT ID/default:device:DEVICENAME
The ID of the device to be associated with the thing.
The ID should be in the following format.
urn:tdm:REGION/ACCOUNT ID/default:device:DEVICENAME
The version of the user's namespace. Defaults to the latest version of the user's namespace.
The version of the user's namespace. Defaults to the latest version of the user's namespace.
Consumes the builder and constructs a AssociateEntityToThingInput