Struct aws_sdk_iotthingsgraph::input::create_flow_template_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for CreateFlowTemplateInput
Implementations
The workflow DefinitionDocument.
The workflow DefinitionDocument.
The namespace version in which the workflow is to be created.
If no value is specified, the latest version is used by default.
The namespace version in which the workflow is to be created.
If no value is specified, the latest version is used by default.
Consumes the builder and constructs a CreateFlowTemplateInput