Struct aws_sdk_iotthingsgraph::input::create_system_instance_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for CreateSystemInstanceInput
Implementations
Appends an item to tags.
To override the contents of this collection use set_tags.
Metadata, consisting of key-value pairs, that can be used to categorize your system instances.
Metadata, consisting of key-value pairs, that can be used to categorize your system instances.
A document that defines an entity.
A document that defines an entity.
The target type of the deployment. Valid values are GREENGRASS and CLOUD.
The target type of the deployment. Valid values are GREENGRASS and CLOUD.
The name of the Greengrass group where the system instance will be deployed. This value is required if
the value of the target parameter is GREENGRASS.
The name of the Greengrass group where the system instance will be deployed. This value is required if
the value of the target parameter is GREENGRASS.
The name of the Amazon Simple Storage Service bucket that will be used to store and deploy the system instance's resource file. This value is required if
the value of the target parameter is GREENGRASS.
The name of the Amazon Simple Storage Service bucket that will be used to store and deploy the system instance's resource file. This value is required if
the value of the target parameter is GREENGRASS.
An object that specifies whether cloud metrics are collected in a deployment and, if so, what role is used to collect metrics.
An object that specifies whether cloud metrics are collected in a deployment and, if so, what role is used to collect metrics.
The ARN of the IAM role that AWS IoT Things Graph will assume when it executes the flow. This role must have
read and write access to AWS Lambda and AWS IoT and any other AWS services that the flow uses when it executes. This
value is required if the value of the target parameter is CLOUD.
The ARN of the IAM role that AWS IoT Things Graph will assume when it executes the flow. This role must have
read and write access to AWS Lambda and AWS IoT and any other AWS services that the flow uses when it executes. This
value is required if the value of the target parameter is CLOUD.
Consumes the builder and constructs a CreateSystemInstanceInput