Struct aws_sdk_iotthingsgraph::input::create_system_template_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for CreateSystemTemplateInput
Implementations
The DefinitionDocument used to create the system.
The DefinitionDocument used to create the system.
The namespace version in which the system is to be created.
If no value is specified, the latest version is used by default.
The namespace version in which the system is to be created.
If no value is specified, the latest version is used by default.
Consumes the builder and constructs a CreateSystemTemplateInput