Struct aws_sdk_iotthingsgraph::input::search_things_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for SearchThingsInput
Implementations
The ID of the entity to which the things are associated.
The IDs should be in the following format.
urn:tdm:REGION/ACCOUNT ID/default:device:DEVICENAME
The ID of the entity to which the things are associated.
The IDs should be in the following format.
urn:tdm:REGION/ACCOUNT ID/default:device:DEVICENAME
The string that specifies the next page of results. Use this when you're paginating results.
The string that specifies the next page of results. Use this when you're paginating results.
The maximum number of results to return in the response.
The maximum number of results to return in the response.
The version of the user's namespace. Defaults to the latest version of the user's namespace.
The version of the user's namespace. Defaults to the latest version of the user's namespace.
Consumes the builder and constructs a SearchThingsInput