Struct aws_sdk_iotthingsgraph::input::AssociateEntityToThingInput [−][src]
#[non_exhaustive]pub struct AssociateEntityToThingInput {
pub thing_name: Option<String>,
pub entity_id: Option<String>,
pub namespace_version: Option<i64>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.thing_name: Option<String>The name of the thing to which the entity is to be associated.
entity_id: Option<String>The ID of the device to be associated with the thing.
The ID should be in the following format.
urn:tdm:REGION/ACCOUNT ID/default:device:DEVICENAME
namespace_version: Option<i64>The version of the user's namespace. Defaults to the latest version of the user's namespace.
Implementations
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<AssociateEntityToThing, AwsErrorRetryPolicy>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<AssociateEntityToThing, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<AssociateEntityToThing>
Creates a new builder-style object to manufacture AssociateEntityToThingInput