Struct aws_sdk_iotthingsgraph::input::CreateSystemInstanceInput [−][src]
#[non_exhaustive]pub struct CreateSystemInstanceInput {
pub tags: Option<Vec<Tag>>,
pub definition: Option<DefinitionDocument>,
pub target: Option<DeploymentTarget>,
pub greengrass_group_name: Option<String>,
pub s3_bucket_name: Option<String>,
pub metrics_configuration: Option<MetricsConfiguration>,
pub flow_actions_role_arn: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.Metadata, consisting of key-value pairs, that can be used to categorize your system instances.
definition: Option<DefinitionDocument>A document that defines an entity.
target: Option<DeploymentTarget>The target type of the deployment. Valid values are GREENGRASS and CLOUD.
greengrass_group_name: Option<String>The name of the Greengrass group where the system instance will be deployed. This value is required if
the value of the target parameter is GREENGRASS.
s3_bucket_name: Option<String>The name of the Amazon Simple Storage Service bucket that will be used to store and deploy the system instance's resource file. This value is required if
the value of the target parameter is GREENGRASS.
metrics_configuration: Option<MetricsConfiguration>An object that specifies whether cloud metrics are collected in a deployment and, if so, what role is used to collect metrics.
flow_actions_role_arn: Option<String>The ARN of the IAM role that AWS IoT Things Graph will assume when it executes the flow. This role must have
read and write access to AWS Lambda and AWS IoT and any other AWS services that the flow uses when it executes. This
value is required if the value of the target parameter is CLOUD.
Implementations
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<CreateSystemInstance, AwsErrorRetryPolicy>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<CreateSystemInstance, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<CreateSystemInstance>
Creates a new builder-style object to manufacture CreateSystemInstanceInput
Metadata, consisting of key-value pairs, that can be used to categorize your system instances.
A document that defines an entity.
The target type of the deployment. Valid values are GREENGRASS and CLOUD.
The name of the Greengrass group where the system instance will be deployed. This value is required if
the value of the target parameter is GREENGRASS.
The name of the Amazon Simple Storage Service bucket that will be used to store and deploy the system instance's resource file. This value is required if
the value of the target parameter is GREENGRASS.
An object that specifies whether cloud metrics are collected in a deployment and, if so, what role is used to collect metrics.
The ARN of the IAM role that AWS IoT Things Graph will assume when it executes the flow. This role must have
read and write access to AWS Lambda and AWS IoT and any other AWS services that the flow uses when it executes. This
value is required if the value of the target parameter is CLOUD.