Struct aws_sdk_iotthingsgraph::input::GetSystemTemplateRevisionsInput [−][src]
#[non_exhaustive]pub struct GetSystemTemplateRevisionsInput {
pub id: Option<String>,
pub next_token: Option<String>,
pub max_results: Option<i32>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: Option<String>The ID of the system template.
The ID should be in the following format.
urn:tdm:REGION/ACCOUNT ID/default:system:SYSTEMNAME
next_token: Option<String>The string that specifies the next page of results. Use this when you're paginating results.
max_results: Option<i32>The maximum number of results to return in the response.
Implementations
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<GetSystemTemplateRevisions, AwsErrorRetryPolicy>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<GetSystemTemplateRevisions, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<GetSystemTemplateRevisions>
Creates a new builder-style object to manufacture GetSystemTemplateRevisionsInput