Struct aws_sdk_iotthingsgraph::input::UpdateSystemTemplateInput [−][src]
#[non_exhaustive]pub struct UpdateSystemTemplateInput {
pub id: Option<String>,
pub definition: Option<DefinitionDocument>,
pub compatible_namespace_version: Option<i64>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: Option<String>The ID of the system to be updated.
The ID should be in the following format.
urn:tdm:REGION/ACCOUNT ID/default:system:SYSTEMNAME
definition: Option<DefinitionDocument>The DefinitionDocument that contains the updated system definition.
compatible_namespace_version: Option<i64>The version of the user's namespace. Defaults to the latest version of the user's namespace.
If no value is specified, the latest version is used by default.
Implementations
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<UpdateSystemTemplate, AwsErrorRetryPolicy>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<UpdateSystemTemplate, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<UpdateSystemTemplate>
Creates a new builder-style object to manufacture UpdateSystemTemplateInput
The ID of the system to be updated.
The ID should be in the following format.
urn:tdm:REGION/ACCOUNT ID/default:system:SYSTEMNAME
The DefinitionDocument that contains the updated system definition.
The version of the user's namespace. Defaults to the latest version of the user's namespace.
If no value is specified, the latest version is used by default.