Struct aws_sdk_iotthingsgraph::input::undeploy_system_instance_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for UndeploySystemInstanceInput
Implementations
The ID of the system instance to remove from its target.
The ID of the system instance to remove from its target.
Consumes the builder and constructs a UndeploySystemInstanceInput