Struct aws_sdk_iotthingsgraph::input::update_flow_template_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for UpdateFlowTemplateInput
Implementations
The ID of the workflow to be updated.
The ID should be in the following format.
urn:tdm:REGION/ACCOUNT ID/default:workflow:WORKFLOWNAME
The ID of the workflow to be updated.
The ID should be in the following format.
urn:tdm:REGION/ACCOUNT ID/default:workflow:WORKFLOWNAME
The DefinitionDocument that contains the updated workflow definition.
The DefinitionDocument that contains the updated workflow definition.
The version of the user's namespace.
If no value is specified, the latest version is used by default. Use the GetFlowTemplateRevisions if you want to find earlier revisions of the flow
to update.
The version of the user's namespace.
If no value is specified, the latest version is used by default. Use the GetFlowTemplateRevisions if you want to find earlier revisions of the flow
to update.
Consumes the builder and constructs a UpdateFlowTemplateInput