Struct aws_sdk_iotthingsgraph::input::update_system_template_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for UpdateSystemTemplateInput
Implementations
The ID of the system to be updated.
The ID should be in the following format.
urn:tdm:REGION/ACCOUNT ID/default:system:SYSTEMNAME
The ID of the system to be updated.
The ID should be in the following format.
urn:tdm:REGION/ACCOUNT ID/default:system:SYSTEMNAME
The DefinitionDocument that contains the updated system definition.
The DefinitionDocument that contains the updated system definition.
The version of the user's namespace. Defaults to the latest version of the user's namespace.
If no value is specified, the latest version is used by default.
The version of the user's namespace. Defaults to the latest version of the user's namespace.
If no value is specified, the latest version is used by default.
Consumes the builder and constructs a UpdateSystemTemplateInput