Struct aws_sdk_iotthingsgraph::input::upload_entity_definitions_input::Builder[][src]

#[non_exhaustive]
pub struct Builder { /* fields omitted */ }
Implementations

The DefinitionDocument that defines the updated entities.

The DefinitionDocument that defines the updated entities.

A Boolean that specifies whether to synchronize with the latest version of the public namespace. If set to true, the upload will create a new namespace version.

A Boolean that specifies whether to synchronize with the latest version of the public namespace. If set to true, the upload will create a new namespace version.

A Boolean that specifies whether to deprecate all entities in the latest version before uploading the new DefinitionDocument. If set to true, the upload will create a new namespace version.

A Boolean that specifies whether to deprecate all entities in the latest version before uploading the new DefinitionDocument. If set to true, the upload will create a new namespace version.

Consumes the builder and constructs a UploadEntityDefinitionsInput