Struct aws_sdk_iotthingsgraph::model::EntityFilter [−][src]
#[non_exhaustive]pub struct EntityFilter {
pub name: Option<EntityFilterName>,
pub value: Option<Vec<String>>,
}Expand description
An object that filters an entity search. Multiple filters function as OR criteria in the search. For example a search that includes
a NAMESPACE and a REFERENCED_ENTITY_ID filter searches for entities in the specified namespace that use the entity specified by
the value of REFERENCED_ENTITY_ID.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: Option<EntityFilterName>The name of the entity search filter field. REFERENCED_ENTITY_ID filters on entities that are used by the entity in the result set. For example,
you can filter on the ID of a property that is used in a state.
value: Option<Vec<String>>An array of string values for the search filter field. Multiple values function as AND criteria in the search.
Implementations
Creates a new builder-style object to manufacture EntityFilter