Struct aws_sdk_iotthingsgraph::output::create_system_instance_output::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for CreateSystemInstanceOutput
Implementations
The summary object that describes the new system instance.
The summary object that describes the new system instance.
Consumes the builder and constructs a CreateSystemInstanceOutput