#[non_exhaustive]pub struct Builder { /* private fields */ }Expand description
A builder for DeploySystemInstanceOutput
Implementations
An object that contains summary information about a system instance that was deployed.
An object that contains summary information about a system instance that was deployed.
The ID of the Greengrass deployment used to deploy the system instance.
The ID of the Greengrass deployment used to deploy the system instance.
Consumes the builder and constructs a DeploySystemInstanceOutput