Struct aws_sdk_iotthingsgraph::output::ListFlowExecutionMessagesOutput [−][src]
#[non_exhaustive]pub struct ListFlowExecutionMessagesOutput {
pub messages: Option<Vec<FlowExecutionMessage>>,
pub next_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.messages: Option<Vec<FlowExecutionMessage>>A list of objects that contain information about events in the specified flow execution.
next_token: Option<String>The string to specify as nextToken when you request the next page of results.
Implementations
Creates a new builder-style object to manufacture ListFlowExecutionMessagesOutput