Struct aws_sdk_iotthingsgraph::output::SearchEntitiesOutput [−][src]
#[non_exhaustive]pub struct SearchEntitiesOutput {
pub descriptions: Option<Vec<EntityDescription>>,
pub next_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.descriptions: Option<Vec<EntityDescription>>An array of descriptions for each entity returned in the search result.
next_token: Option<String>The string to specify as nextToken when you request the next page of results.
Implementations
An array of descriptions for each entity returned in the search result.
The string to specify as nextToken when you request the next page of results.
Creates a new builder-style object to manufacture SearchEntitiesOutput