Struct aws_sdk_iotthingsgraph::output::SearchFlowTemplatesOutput [−][src]
#[non_exhaustive]pub struct SearchFlowTemplatesOutput {
pub summaries: Option<Vec<FlowTemplateSummary>>,
pub next_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.summaries: Option<Vec<FlowTemplateSummary>>An array of objects that contain summary information about each workflow in the result set.
next_token: Option<String>The string to specify as nextToken when you request the next page of results.
Implementations
An array of objects that contain summary information about each workflow in the result set.
The string to specify as nextToken when you request the next page of results.
Creates a new builder-style object to manufacture SearchFlowTemplatesOutput