Struct aws_sdk_iotthingsgraph::output::undeploy_system_instance_output::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for UndeploySystemInstanceOutput
Implementations
An object that contains summary information about the system instance that was removed from its target.
An object that contains summary information about the system instance that was removed from its target.
Consumes the builder and constructs a UndeploySystemInstanceOutput